SWDEV-351966 - Remove hipRegisterTracerCallback from dispatch table
Change-Id: Ib343e2c8414a98c0cee6c60fb74a47bb859d8f45
This commit is contained in:
committed by
Anusha Godavarthy Surya
parent
afc28b091e
commit
d347f1d67d
@@ -534,7 +534,6 @@ hipError_t hipPointerSetAttribute(const void* value, hipPointer_attribute attrib
|
||||
hipDeviceptr_t ptr);
|
||||
hipError_t hipProfilerStart();
|
||||
hipError_t hipProfilerStop();
|
||||
void hipRegisterTracerCallback(const void* function);
|
||||
hipError_t hipRuntimeGetVersion(int* runtimeVersion);
|
||||
hipError_t hipSetDevice(int deviceId);
|
||||
hipError_t hipSetDeviceFlags(unsigned flags);
|
||||
@@ -1091,7 +1090,6 @@ void UpdateHipDispatchTable(HipDispatchTable* ptrDispatchTable) {
|
||||
ptrDispatchTable->hipPointerSetAttribute_fn = hip::hipPointerSetAttribute;
|
||||
ptrDispatchTable->hipProfilerStart_fn = hip::hipProfilerStart;
|
||||
ptrDispatchTable->hipProfilerStop_fn = hip::hipProfilerStop;
|
||||
ptrDispatchTable->hipRegisterTracerCallback_fn = hip::hipRegisterTracerCallback;
|
||||
ptrDispatchTable->hipRuntimeGetVersion_fn = hip::hipRuntimeGetVersion;
|
||||
ptrDispatchTable->hipSetDevice_fn = hip::hipSetDevice;
|
||||
ptrDispatchTable->hipSetDeviceFlags_fn = hip::hipSetDeviceFlags;
|
||||
|
||||
@@ -45,13 +45,11 @@ const char* hipKernelNameRefByPtr(const void* host_function, hipStream_t stream)
|
||||
return (host_function != nullptr) ? PlatformState::instance().getStatFuncName(host_function)
|
||||
: nullptr;
|
||||
}
|
||||
|
||||
void hipRegisterTracerCallback(const void* function) {
|
||||
typedef int (*fptr)(activity_domain_t domain, uint32_t operation_id, void* data);
|
||||
fptr my_fptr = reinterpret_cast<fptr>(const_cast<void*>(function));
|
||||
activity_prof::report_activity.store(my_fptr, std::memory_order_relaxed);
|
||||
}
|
||||
|
||||
const char* hipApiName(uint32_t id) { return hip_api_name(id); }
|
||||
|
||||
} // namespace hip
|
||||
|
||||
extern "C" void hipRegisterTracerCallback(int (*function)(activity_domain_t domain,
|
||||
uint32_t operation_id, void* data)) {
|
||||
activity_prof::report_activity.store(function, std::memory_order_relaxed);
|
||||
}
|
||||
|
||||
@@ -1280,9 +1280,6 @@ hipError_t hipPointerSetAttribute(const void* value, hipPointer_attribute attrib
|
||||
}
|
||||
hipError_t hipProfilerStart() { return hip::GetHipDispatchTable()->hipProfilerStart_fn(); }
|
||||
hipError_t hipProfilerStop() { return hip::GetHipDispatchTable()->hipProfilerStop_fn(); }
|
||||
extern "C" void hipRegisterTracerCallback(const void* function) {
|
||||
return hip::GetHipDispatchTable()->hipRegisterTracerCallback_fn(function);
|
||||
}
|
||||
hipError_t hipRuntimeGetVersion(int* runtimeVersion) {
|
||||
return hip::GetHipDispatchTable()->hipRuntimeGetVersion_fn(runtimeVersion);
|
||||
}
|
||||
|
||||
Reference in New Issue
Block a user